SynthDefs
=========

Building
--------

- context managers
- ugen "capture"
- parameters
- multi-channel expansion
- names

Inspection
----------

- printing
- graphing

Lifecycle
---------

- allocation
- freeing
